@@ -54,7 +54,7 @@ class Zwave:
         :param uid: Device UID, something like hdm:ZWave:CBC56091/24
         :return: False, if device is offline, else True
         """
-        return False if self.status == 1 else True
+        return bool(self.status)
 
 
 def get_device_type_from_element_uid(element_uid: str) -> str:
@@ -74,7 +74,10 @@ def get_device_uid_from_setting_uid(setting_uid: str) -> str:
     :param setting_uid: Setting UID, something like lis.hdm:ZWave:EB5A9F6C/2
     :return: Device UID, something like hdm:ZWave:EB5A9F6C/2
     """
-    return setting_uid.split(".", 1)[-1]
+    setting_uid = setting_uid.split(".", 1)[-1]
+    if setting_uid.endswith("secure"):
+        return setting_uid.rsplit(":", 1)[0]
+    return setting_uid
 
 
 def get_device_uid_from_element_uid(element_uid: str) -> str:
